==> h2o_3.18.0.11.tar.gz: h2o/R/datasets.R <==
#' Australia Coastal Data
#' 
#' Temperature, soil moisture, runoff, and other environmental measurements from
#' the Australia coast. The data is available from \url{http://cs.colby.edu/courses/S11/cs251/labs/lab07/AustraliaSubset.csv}.
#' 
#' @docType data
#' @keywords datasets
#' @name australia
#' @format A data frame with 251 rows and 8 columns
NULL

#' United States Congressional Voting Records 1984
#' 
#' This data set includes votes for each of the U.S. House of Representatives Congressmen on the 16 
#' key votes identified by the CQA. The CQA lists nine different types of votes: voted for, paired for, 
#' and announced for (these three simplified to yea), voted against, paired against, and announced 
#' against (these three simplified to nay), voted present, voted present to avoid conflict of interest, 
#' and did not vote or otherwise make a position known (these three simplified to an unknown disposition).
#' 
#' @docType data
#' @keywords datasets
#' @name housevotes
#' @format A data frame with 435 rows and 17 columns
#' @source Congressional Quarterly Almanac, 98th Congress, 2nd session 1984, Volume XL: Congressional Quarterly Inc., Washington, D.C., 1985
#' @references Newman, D.J. & Hettich, S. & Blake, C.L. & Merz, C.J. (1998). UCI Repository of machine 
#' learning databases [http://www.ics.uci.edu/~mlearn/MLRepository.html]. Irvine, CA: University of 
#' California, Department of Information and Computer Science.
NULL

#' Edgar Anderson's Iris Data
#' 
#' Measurements in centimeters of the sepal length and width and petal length and width, 
#' respectively, for three species of iris flowers.
#' 
#' @docType data
#' @keywords datasets
#' @name iris
#' @format A data frame with 150 rows and 5 columns
#' @source Fisher, R. A. (1936) The use of multiple measurements in taxonomic problems. Annals of Eugenics, 7, Part II, 179-188.
#'
#' The data were collected by Anderson, Edgar (1935). The irises of the Gaspe Peninsula, Bulletin of the American Iris Society, 59, 2-5.
NULL

#' Prostate Cancer Study
#' 
#' Baseline exam results on prostate cancer patients from Dr. Donn Young at The Ohio State 
#' University Comprehensive Cancer Center. 
#' 
#' @docType data
#' @keywords datasets
#' @name prostate
#' @format A data frame with 380 rows and 9 columns
#' @source Hosmer and Lemeshow (2000) Applied Logistic Regression: Second Edition.
NULL

#' Muscular Actuations for Walking Subject
#' 
#' The musculoskeletal model, experimental data, settings files, and results 
#' for three-dimensional, muscle-actuated simulations at walking speed as 
#' described in Hamner and Delp (2013). Simulations were generated using OpenSim 2.4.
#' The data is available from \url{https://simtk.org/project/xml/downloads.xml?group_id=603}.
#' 
#' @docType data
#' @keywords datasets
#' @name walking
#' @format A data frame with 151 rows and 124 columns
#' @references Hamner, S.R., Delp, S.L. Muscle contributions to fore-aft and vertical body mass center accelerations over a range of running speeds. Journal of Biomechanics, vol 46, pp 780-787. (2013) 
NULL

==> h2o_3.36.0.2.tar.gz: h2o/R/datasets.R <==
#' Australia Coastal Data
#' 
#' Temperature, soil moisture, runoff, and other environmental measurements from
#' the Australia coast. The data is available from https://cs.colby.edu/courses/S11/cs251/labs/lab07/AustraliaSubset.csv.
#' 
#' @docType data
#' @keywords datasets
#' @name australia
#' @format A data frame with 251 rows and 8 columns
NULL

#' United States Congressional Voting Records 1984
#' 
#' This data set includes votes for each of the U.S. House of Representatives Congressmen on the 16 
#' key votes identified by the CQA. The CQA lists nine different types of votes: voted for, paired for, 
#' and announced for (these three simplified to yea), voted against, paired against, and announced 
#' against (these three simplified to nay), voted present, voted present to avoid conflict of interest, 
#' and did not vote or otherwise make a position known (these three simplified to an unknown disposition).
#' 
#' @docType data
#' @keywords datasets
#' @name housevotes
#' @format A data frame with 435 rows and 17 columns
#' @source Congressional Quarterly Almanac, 98th Congress, 2nd session 1984, Volume XL: Congressional Quarterly Inc., Washington, D.C., 1985
#' @references Newman, D.J. & Hettich, S. & Blake, C.L. & Merz, C.J. (1998). UCI Repository of machine 
#' learning databases [https://www.ics.uci.edu/~mlearn/MLRepository.html]. Irvine, CA: University of 
#' California, Department of Information and Computer Science.
NULL

#' Edgar Anderson's Iris Data
#' 
#' Measurements in centimeters of the sepal length and width and petal length and width, 
#' respectively, for three species of iris flowers.
#' 
#' @docType data
#' @keywords datasets
#' @name iris
#' @format A data frame with 150 rows and 5 columns
#' @source Fisher, R. A. (1936) The use of multiple measurements in taxonomic problems. Annals of Eugenics, 7, Part II, 179-188.
#'
#' The data were collected by Anderson, Edgar (1935). The irises of the Gaspe Peninsula, Bulletin of the American Iris Society, 59, 2-5.
NULL

#' Prostate Cancer Study
#' 
#' Baseline exam results on prostate cancer patients from Dr. Donn Young at The Ohio State 
#' University Comprehensive Cancer Center. 
#' 
#' @docType data
#' @keywords datasets
#' @name prostate
#' @format A data frame with 380 rows and 9 columns
#' @source Hosmer and Lemeshow (2000) Applied Logistic Regression: Second Edition.
NULL

#' Muscular Actuations for Walking Subject
#' 
#' The musculoskeletal model, experimental data, settings files, and results 
#' for three-dimensional, muscle-actuated simulations at walking speed as 
#' described in Hamner and Delp (2013). Simulations were generated using OpenSim 2.4.
#' The data is available from \url{https://simtk.org/frs/index.php?group_id=603}.
#' 
#' @docType data
#' @keywords datasets
#' @name walking
#' @format A data frame with 151 rows and 124 columns
#' @references Hamner, S.R., Delp, S.L. Muscle contributions to fore-aft and vertical body mass center accelerations over a range of running speeds. Journal of Biomechanics, vol 46, pp 780-787. (2013) 
NULL
